#!/bin/bash
set -u

function msg () { echo -e "$*"; }
function cmd () { echo -e "Executing: $*"; $*; return $?; }
function bail () { echo -e "\nError: ${1:-Unkown Error}\n"; exit ${2:-1}; }

export TestID=${1:-1}
export P4BIN=${2:-p4}
export P4PORT=${3:-1666}
export P4USER=${4:-bruno}
export P4CLIENT=TestWS.$TestID
export P4CONFIG=/tmp/.p4config.$TestID
declare -i ExitCode=0
declare TmpFile=/tmp/tmpFile.$TestID.$$.$RANDOM
declare RootDir=/tmp/$P4CLIENT
declare SSTFile=DeepThought-Components.cbdsst
declare MainlineStream=//DeepThought/Components/main
declare DevStream=//DeepThought/Components/dev

echo -e "Running Test $TestID\n$0 $*\n"

/bin/rm -f "$P4CONFIG"
echo -e "P4PORT=$P4PORT\nP4USER=$P4USER\nP4CLIENT=$P4CLIENT\nP4IGNORE=.p4ignore\nP4TICKETS=$PWD/.p4tickets\nP4ENVIRO=$PWD/.p4enviro\nP4TRUST=$PWD/.p4trust" > $P4CONFIG
echo -e "Wrote this P4CONFIG file $P4CONFIG:\n$(cat $P4CONFIG)"

echo -e "Client: $P4CLIENT\n\nOwner: bruno\n\nRoot: $RootDir\n\nStream: $DevStream\n\n" > $TmpFile

$P4BIN -s client -i < $TmpFile || bail "Failed to create workspace [$P4CLIENT]."

msg "Sync specifying stream root $DevStream/... in depot with StreamDepth>1."

cmd $P4BIN -s -c $P4CLIENT sync -q $DevStream/... ||\
   bail "Failed to sync specifying $DevStream/... in workspace $P4CLIENT."

exit 0
